@@ -5,6 +5,7 @@ import getpass
 from typing import Literal
 import click
 import typer
+import shutil
 from modaic import AutoProgram
 
 from utils.cache import (
@@ -306,7 +307,11 @@ def run_interactive(
                     f.write(task + "\n")
 
             click.echo(f"\n{CYAN}⏺{RESET} Thinking...", nl=True)
-            result = agent(task=task)
+            try:
+                result = agent(task=task)
+            except Exception as e:
+                click.echo(f"\n{RED}⏺ Error: {e}{RESET}")
+                continue
 
             click.echo(f"\n{CYAN}⏺{RESET} {render_markdown(result.answer)}")
 
@@ -478,6 +483,10 @@ def cli(
 
 
 def main() -> None:
+    # Clear modaic cache on startup
+    modaic_cache = os.path.expanduser("~/.cache/modaic")
+    if os.path.exists(modaic_cache):
+        shutil.rmtree(modaic_cache)
     app()
 
 
