@@ -3,7 +3,7 @@ import re
 import shutil
 from .constants import RESET, BOLD, DIM, BLUE, BANNER_ART, GREEN
 import click
-from typing import Optional
+
 
 def separator() -> str:
     """
@@ -12,30 +12,31 @@ def separator() -> str:
     size = shutil.get_terminal_size() or 800
     return f"{DIM}{'─' * size.columns}{RESET}"
 
+
 def render_markdown(text: str) -> str:
     """
     Convert markdown formatting to ANSI escape codes.
-    
+
     Supports:
     - Bold: **text** or __text__
     - Italic: *text* or _text_
     - Code: `text`
     - Strikethrough: ~~text~~
-    
+
     Args:
         text: Input string with markdown formatting
-        
+
     Returns:
         String with ANSI escape codes
-        
+
     Raises:
         TypeError: If text is not a string
     """
     assert isinstance(text, str), "text must be a str"
-    
+
     if not text:
         return text
-    
+
     # Define ANSI codes (with fallback if not defined globally)
     try:
         bold = BOLD
@@ -48,12 +49,12 @@ def render_markdown(text: str) -> str:
         strikethrough = "\033[9m"
     else:
         # Assume other codes follow same pattern if BOLD/RESET are defined
-        italic = getattr(__builtins__, 'ITALIC', "\033[3m")
-        dim = getattr(__builtins__, 'DIM', "\033[2m")
-        strikethrough = getattr(__builtins__, 'STRIKETHROUGH', "\033[9m")
-    
+        italic = getattr(__builtins__, "ITALIC", "\033[3m")
+        dim = getattr(__builtins__, "DIM", "\033[2m")
+        strikethrough = getattr(__builtins__, "STRIKETHROUGH", "\033[9m")
+
     result = text
-    
+
     # Process in order to handle nested formatting correctly
     # 1. Code blocks (prevent them from being processed as other formatting)
     code_placeholder = "\x00CODE\x00"
@@ -61,24 +62,26 @@ def render_markdown(text: str) -> str:
     for match in re.finditer(r"`([^`]+)`", result):
         code_matches.append(f"{dim}{match.group(1)}{reset}")
     result = re.sub(r"`[^`]+`", code_placeholder, result)
-    
+
     # 2. Bold (both ** and __)
     # Use non-greedy matching and handle newlines
     result = re.sub(r"\*\*(.+?)\*\*", f"{bold}\\1{reset}", result, flags=re.DOTALL)
     result = re.sub(r"__(.+?)__", f"{bold}\\1{reset}", result, flags=re.DOTALL)
-    
+
     # 3. Italic (both * and _)
     # Exclude cases where * or _ is part of bold syntax or at word boundaries
-    result = re.sub(r"(?<!\*)\*(?!\*)([^\*]+?)(?<!\*)\*(?!\*)", f"{italic}\\1{reset}", result)
+    result = re.sub(
+        r"(?<!\*)\*(?!\*)([^\*]+?)(?<!\*)\*(?!\*)", f"{italic}\\1{reset}", result
+    )
     result = re.sub(r"(?<!_)_(?!_)([^_]+?)(?<!_)_(?!_)", f"{italic}\\1{reset}", result)
-    
+
     # 4. Strikethrough
     result = re.sub(r"~~(.+?)~~", f"{strikethrough}\\1{reset}", result, flags=re.DOTALL)
-    
+
     # 5. Restore code blocks
     for code_match in code_matches:
         result = result.replace(code_placeholder, code_match, 1)
-    
+
     return result
 
 
@@ -86,25 +89,25 @@ def render_markdown(text: str) -> str:
 def render_markdown_simple(text: str) -> str:
     """
     Convert basic markdown bold syntax to ANSI bold (improved version).
-    
+
     Args:
         text: Input string with markdown formatting
-        
+
     Returns:
         String with ANSI bold formatting
-        
+
     Raises:
         TypeError: If text is not a string
     """
     assert isinstance(text, str), "text must be a str"
-    
+
     if not text:
         return text
-    
+
     # Define ANSI codes with fallback
-    bold = getattr(__builtins__, 'BOLD', None) or "\033[1m"
-    reset = getattr(__builtins__, 'RESET', None) or "\033[0m"
-    
+    bold = getattr(__builtins__, "BOLD", None) or "\033[1m"
+    reset = getattr(__builtins__, "RESET", None) or "\033[0m"
+
     # Use re.DOTALL to handle multi-line bold text
     # Non-greedy matching to handle multiple bold sections
     return re.sub(r"\*\*(.+?)\*\*", f"{bold}\\1{reset}", text, flags=re.DOTALL)
@@ -226,6 +229,10 @@ def print_banner(
         b = int(start[2] + (end[2] - start[2]) * t)
         return f"\033[38;2;{r};{g};{b}m"
 
+    def visible_len(text: str) -> int:
+        ansi_escape = re.compile(r"\x1b\[[0-9;]*m")
+        return len(ansi_escape.sub("", text))
+
     right_lines = [
         f"{BOLD}{BLUE}MICROCODE -{RESET} {DIM}An Efficient RLM Terminal Agent{RESET}",
         "",
@@ -247,19 +254,25 @@ def print_banner(
         f"  {BLUE}/q - quit{RESET}",
     ]
 
+    terminal_width = shutil.get_terminal_size().columns
     total_lines = max(len(art_lines), len(right_lines))
     art_width = max((len(line) for line in art_lines), default=0)
+    right_width = max((visible_len(line) for line in right_lines), default=0)
+    min_width_for_art = art_width + 2 + right_width
 
-    banner_lines = []
-    for idx in range(total_lines):
-        left_raw = art_lines[idx] if idx < len(art_lines) else ""
-        left_padded = left_raw.ljust(art_width)
-        if left_raw:
-            left = f"{gradient_color(idx, len(art_lines))}{left_padded}{RESET}"
-        else:
-            left = left_padded
-        right = right_lines[idx] if idx < len(right_lines) else ""
-        banner_lines.append(f"{left}  {right}")
+    if terminal_width < min_width_for_art:
+        banner_lines = right_lines
+    else:
+        banner_lines = []
+        for idx in range(total_lines):
+            left_raw = art_lines[idx] if idx < len(art_lines) else ""
+            left_padded = left_raw.ljust(art_width)
+            if left_raw:
+                left = f"{gradient_color(idx, len(art_lines))}{left_padded}{RESET}"
+            else:
+                left = left_padded
+            right = right_lines[idx] if idx < len(right_lines) else ""
+            banner_lines.append(f"{left}  {right}")
 
     click.echo("\n".join(banner_lines))
 
